Learn R Programming

proteomicdesign (version 2.0)

calculate.cost: Function to calculate the total cost of the multi-stage design

Description

A function to calculate the total cost of the multi-stage design. It is used in the optim.two.stage.appr() as a sub-function.

Usage

calculate.cost(n2, n3, p1, p2)

Arguments

n2
the stage II sample size
n3
the stage III sample size
p1
the number of proteins selected from stage I
p2
the number of proteins selected from stage II