Learn R Programming

proteomicdesign (version 2.0)

calculate.n3: A function to calculate the stage III sample size based on the current design parameters

Description

A function to calculate the stage III sample size based on the current design parameters. It is used to reduce the dimensions of the design parameters in the optimization. The sample size of stage III is calculated by used the known budget, a slack term for the inequality constraint, and the current design parameters from the search.

Usage

calculate.n3(n2, p2, p3)

Arguments

n2
stage II sample size
p2
number of proteins selected from stage I
p3
number of proteins selected from stage II