Learn R Programming

proteomicdesign (version 2.0)

do.one.experiment.t: Simulation function for calculating the expected number of detectable proteins from the three stage proteomic study

Description

Simulation function for calculating the expected number of detectable proteins from the three stage proteomic study. It is used in the optim.two.stage.single().

Usage

do.one.experiment.t(initial)

Arguments

initial
The design parameters selected at the current search