calculate.n3:
A function to calculate the stage III sample size based on the current design parameters
Description
A function to calculate the stage III sample size based on the current design parameters. It is used to reduce the dimensions of the design parameters in the optimization.
The sample size of stage III is calculated by used the known budget, a slack term for the inequality constraint, and the current design parameters from the search.